//go:build enterprise

/*
Copyright (c) Edgeless Systems GmbH

SPDX-License-Identifier: AGPL-3.0-only
*/

package measurements

import "github.com/edgelesssys/constellation/v2/internal/cloud/cloudprovider"

// Regenerate the measurements by running go generate.
// The enterprise build tag is required to validate the measurements using production
// sigstore certificates.
//go:generate go run -tags enterprise measurement-generator/generate.go

// DefaultsFor provides the default measurements for given cloud provider.
func DefaultsFor(provider cloudprovider.Provider) M {
	switch provider {
	case cloudprovider.AWS:
		return M{
			0: {
				Expected: [32]byte{
					0x73, 0x7f, 0x76, 0x7a, 0x12, 0xf5, 0x4e, 0x70,
					0xee, 0xcb, 0xc8, 0x68, 0x40, 0x11, 0x32, 0x3a,
					0xe2, 0xfe, 0x2d, 0xd9, 0xf9, 0x07, 0x85, 0x57,
					0x79, 0x69, 0xd7, 0xa2, 0x01, 0x3e, 0x8c, 0x12,
				},
				WarnOnly: true,
			},
			2: {
				Expected: [32]byte{
					0x3d, 0x45, 0x8c, 0xfe, 0x55, 0xcc, 0x03, 0xea,
					0x1f, 0x44, 0x3f, 0x15, 0x62, 0xbe, 0xec, 0x8d,
					0xf5, 0x1c, 0x75, 0xe1, 0x4a, 0x9f, 0xcf, 0x9a,
					0x72, 0x34, 0xa1, 0x3f, 0x19, 0x8e, 0x79, 0x69,
				},
				WarnOnly: true,
			},
			3: {
				Expected: [32]byte{
					0x3d, 0x45, 0x8c, 0xfe, 0x55, 0xcc, 0x03, 0xea,
					0x1f, 0x44, 0x3f, 0x15, 0x62, 0xbe, 0xec, 0x8d,
					0xf5, 0x1c, 0x75, 0xe1, 0x4a, 0x9f, 0xcf, 0x9a,
					0x72, 0x34, 0xa1, 0x3f, 0x19, 0x8e, 0x79, 0x69,
				},
				WarnOnly: true,
			},
			4: {
				Expected: [32]byte{
					0x19, 0x2e, 0xf5, 0xbd, 0x47, 0x65, 0x8c, 0x09,
					0x5c, 0xba, 0x1f, 0x55, 0xb7, 0x6c, 0x3f, 0x43,
					0x8a, 0xc5, 0xc3, 0xa8, 0xcd, 0x82, 0xf3, 0x49,
					0x2c, 0x8b, 0xe5, 0x42, 0xa5, 0x55, 0xd1, 0xf4,
				},
				WarnOnly: false,
			},
			5: {
				Expected: [32]byte{
					0xbb, 0x41, 0xff, 0xb0, 0xf7, 0xc0, 0xa8, 0xe0,
					0xc2, 0x9f, 0x1e, 0x71, 0x32, 0xf2, 0xb7, 0xb5,
					0xe2, 0xf3, 0x98, 0x8e, 0xd5, 0xb3, 0x9a, 0x75,
					0x09, 0xda, 0x0a, 0x7d, 0x19, 0x79, 0x7d, 0x21,
				},
				WarnOnly: true,
			},
			6: {
				Expected: [32]byte{
					0x3d, 0x45, 0x8c, 0xfe, 0x55, 0xcc, 0x03, 0xea,
					0x1f, 0x44, 0x3f, 0x15, 0x62, 0xbe, 0xec, 0x8d,
					0xf5, 0x1c, 0x75, 0xe1, 0x4a, 0x9f, 0xcf, 0x9a,
					0x72, 0x34, 0xa1, 0x3f, 0x19, 0x8e, 0x79, 0x69,
				},
				WarnOnly: true,
			},
			7: {
				Expected: [32]byte{
					0x12, 0x0e, 0x49, 0x8d, 0xb2, 0xa2, 0x24, 0xbd,
					0x51, 0x2b, 0x6e, 0xfc, 0x9b, 0x02, 0x34, 0xf8,
					0x43, 0xe1, 0x0b, 0xf0, 0x61, 0xeb, 0x7a, 0x76,
					0xec, 0xca, 0x55, 0x09, 0xa2, 0x23, 0x89, 0x01,
				},
				WarnOnly: true,
			},
			8: {
				Expected: [32]byte{
					0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
					0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
					0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
					0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
				},
				WarnOnly: false,
			},
			9: {
				Expected: [32]byte{
					0x08, 0x76, 0xd1, 0xde, 0x84, 0xda, 0x5d, 0xfa,
					0x1b, 0xe9, 0x65, 0xbe, 0x13, 0x75, 0x5b, 0x50,
					0x71, 0xac, 0x7e, 0x14, 0x1b, 0xa1, 0xc7, 0xf2,
					0x4c, 0x1e, 0x1c, 0x99, 0xeb, 0x2d, 0xe6, 0x61,
				},
				WarnOnly: false,
			},
			11: {
				Expected: [32]byte{
					0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
					0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
					0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
					0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
				},
				WarnOnly: false,
			},
			12: {
				Expected: [32]byte{
					0x12, 0x7a, 0xbc, 0x0a, 0x6e, 0x4f, 0x6b, 0x42,
					0xc0, 0xce, 0xbd, 0xb0, 0x29, 0x26, 0x2b, 0x32,
					0xfa, 0x77, 0xf9, 0x2f, 0x69, 0x6d, 0x1f, 0x7d,
					0x42, 0x9b, 0xfa, 0x87, 0x3a, 0x9f, 0x53, 0x5b,
				},
				WarnOnly: false,
			},
			13: {
				Expected: [32]byte{
					0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
					0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
					0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
					0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
				},
				WarnOnly: false,
			},
			14: {
				Expected: [32]byte{
					0xd7, 0xc4, 0xcc, 0x7f, 0xf7, 0x93, 0x30, 0x22,
					0xf0, 0x13, 0xe0, 0x3b, 0xde, 0xe8, 0x75, 0xb9,
					0x17, 0x20, 0xb5, 0xb8, 0x6c, 0xf1, 0x75, 0x3c,
					0xad, 0x83, 0x0f, 0x95, 0xe7, 0x91, 0x92, 0x6f,
				},
				WarnOnly: true,
			},
			15: {
				Expected: [32]byte{
					0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
					0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
					0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
					0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
				},
				WarnOnly: false,
			},
		}
	case cloudprovider.Azure:
		return M{
			1: {
				Expected: [32]byte{
					0x3d, 0x45, 0x8c, 0xfe, 0x55, 0xcc, 0x03, 0xea,
					0x1f, 0x44, 0x3f, 0x15, 0x62, 0xbe, 0xec, 0x8d,
					0xf5, 0x1c, 0x75, 0xe1, 0x4a, 0x9f, 0xcf, 0x9a,
					0x72, 0x34, 0xa1, 0x3f, 0x19, 0x8e, 0x79, 0x69,
				},
				WarnOnly: true,
			},
			2: {
				Expected: [32]byte{
					0x3d, 0x45, 0x8c, 0xfe, 0x55, 0xcc, 0x03, 0xea,
					0x1f, 0x44, 0x3f, 0x15, 0x62, 0xbe, 0xec, 0x8d,
					0xf5, 0x1c, 0x75, 0xe1, 0x4a, 0x9f, 0xcf, 0x9a,
					0x72, 0x34, 0xa1, 0x3f, 0x19, 0x8e, 0x79, 0x69,
				},
				WarnOnly: true,
			},
			3: {
				Expected: [32]byte{
					0x3d, 0x45, 0x8c, 0xfe, 0x55, 0xcc, 0x03, 0xea,
					0x1f, 0x44, 0x3f, 0x15, 0x62, 0xbe, 0xec, 0x8d,
					0xf5, 0x1c, 0x75, 0xe1, 0x4a, 0x9f, 0xcf, 0x9a,
					0x72, 0x34, 0xa1, 0x3f, 0x19, 0x8e, 0x79, 0x69,
				},
				WarnOnly: true,
			},
			4: {
				Expected: [32]byte{
					0xb3, 0x2a, 0x4f, 0xb1, 0x76, 0xc0, 0xff, 0x62,
					0xe6, 0x56, 0x2f, 0x6d, 0x68, 0x41, 0xfa, 0x2c,
					0xb5, 0x86, 0xbd, 0x91, 0x19, 0x8c, 0x51, 0xca,
					0xd9, 0x15, 0x29, 0xf2, 0x01, 0x44, 0xe3, 0xcb,
				},
				WarnOnly: false,
			},
			5: {
				Expected: [32]byte{
					0x69, 0xf7, 0x46, 0x12, 0x29, 0xfd, 0x4b, 0x52,
					0x98, 0x13, 0x4f, 0x4e, 0x08, 0x06, 0x5f, 0x83,
					0x4e, 0x4c, 0x8a, 0xd6, 0x8a, 0x95, 0x21, 0x55,
					0x17, 0x6c, 0xcd, 0x60, 0x3f, 0x65, 0xdc, 0x13,
				},
				WarnOnly: true,
			},
			7: {
				Expected: [32]byte{
					0x34, 0x65, 0x47, 0xa8, 0xce, 0x59, 0x57, 0xaf,
					0x27, 0xe5, 0x52, 0x42, 0x7d, 0x6b, 0x9e, 0x6d,
					0x9c, 0xb5, 0x02, 0xf0, 0x15, 0x6e, 0x91, 0x55,
					0x38, 0x04, 0x51, 0xee, 0xa1, 0xb3, 0xf0, 0xed,
				},
				WarnOnly: true,
			},
			8: {
				Expected: [32]byte{
					0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
					0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
					0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
					0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
				},
				WarnOnly: false,
			},
			9: {
				Expected: [32]byte{
					0xed, 0xd5, 0xb9, 0xcc, 0xa2, 0xed, 0xd4, 0x38,
					0x55, 0xf3, 0x45, 0x45, 0x49, 0x36, 0xe9, 0xf6,
					0xee, 0x1d, 0x7a, 0xb4, 0xb2, 0x2d, 0xc6, 0x8a,
					0xaf, 0x55, 0x78, 0x6b, 0x00, 0x53, 0x1d, 0x4f,
				},
				WarnOnly: false,
			},
			11: {
				Expected: [32]byte{
					0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
					0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
					0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
					0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
				},
				WarnOnly: false,
			},
			12: {
				Expected: [32]byte{
					0x05, 0x1b, 0xbd, 0x8d, 0x94, 0x82, 0xd0, 0x0d,
					0x46, 0x17, 0xdc, 0xfb, 0xcc, 0xc8, 0x8e, 0x1b,
					0xa5, 0x12, 0xcd, 0x06, 0x69, 0x28, 0x01, 0x3f,
					0x4d, 0xe1, 0x84, 0xe7, 0xa8, 0x54, 0x10, 0xdf,
				},
				WarnOnly: false,
			},
			13: {
				Expected: [32]byte{
					0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
					0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
					0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
					0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
				},
				WarnOnly: false,
			},
			14: {
				Expected: [32]byte{
					0xd7, 0xc4, 0xcc, 0x7f, 0xf7, 0x93, 0x30, 0x22,
					0xf0, 0x13, 0xe0, 0x3b, 0xde, 0xe8, 0x75, 0xb9,
					0x17, 0x20, 0xb5, 0xb8, 0x6c, 0xf1, 0x75, 0x3c,
					0xad, 0x83, 0x0f, 0x95, 0xe7, 0x91, 0x92, 0x6f,
				},
				WarnOnly: true,
			},
			15: {
				Expected: [32]byte{
					0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
					0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
					0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
					0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
				},
				WarnOnly: false,
			},
		}
	case cloudprovider.GCP:
		return M{
			0: {
				Expected: [32]byte{
					0x0f, 0x35, 0xc2, 0x14, 0x60, 0x8d, 0x93, 0xc7,
					0xa6, 0xe6, 0x8a, 0xe7, 0x35, 0x9b, 0x4a, 0x8b,
					0xe5, 0xa0, 0xe9, 0x9e, 0xea, 0x91, 0x07, 0xec,
					0xe4, 0x27, 0xc4, 0xde, 0xa4, 0xe4, 0x39, 0xcf,
				},
				WarnOnly: false,
			},
			1: {
				Expected: [32]byte{
					0x74, 0x5f, 0x2f, 0xb4, 0x23, 0x5e, 0x46, 0x47,
					0xaa, 0x0a, 0xd5, 0xac, 0xe7, 0x81, 0xcd, 0x92,
					0x9e, 0xb6, 0x8c, 0x28, 0x87, 0x0e, 0x7d, 0xd5,
					0xd1, 0xa1, 0x53, 0x58, 0x54, 0x32, 0x5e, 0x56,
				},
				WarnOnly: true,
			},
			2: {
				Expected: [32]byte{
					0x3d, 0x45, 0x8c, 0xfe, 0x55, 0xcc, 0x03, 0xea,
					0x1f, 0x44, 0x3f, 0x15, 0x62, 0xbe, 0xec, 0x8d,
					0xf5, 0x1c, 0x75, 0xe1, 0x4a, 0x9f, 0xcf, 0x9a,
					0x72, 0x34, 0xa1, 0x3f, 0x19, 0x8e, 0x79, 0x69,
				},
				WarnOnly: true,
			},
			3: {
				Expected: [32]byte{
					0x3d, 0x45, 0x8c, 0xfe, 0x55, 0xcc, 0x03, 0xea,
					0x1f, 0x44, 0x3f, 0x15, 0x62, 0xbe, 0xec, 0x8d,
					0xf5, 0x1c, 0x75, 0xe1, 0x4a, 0x9f, 0xcf, 0x9a,
					0x72, 0x34, 0xa1, 0x3f, 0x19, 0x8e, 0x79, 0x69,
				},
				WarnOnly: true,
			},
			4: {
				Expected: [32]byte{
					0x6b, 0x08, 0xd0, 0x4d, 0x1a, 0x18, 0xa8, 0x4a,
					0xe6, 0x95, 0x7c, 0xfa, 0xcc, 0xdb, 0xa0, 0x65,
					0x2f, 0xb3, 0xe5, 0x35, 0x1b, 0xf0, 0xf8, 0x3d,
					0x13, 0x58, 0x03, 0x56, 0x97, 0x5a, 0xea, 0xb2,
				},
				WarnOnly: false,
			},
			5: {
				Expected: [32]byte{
					0xcc, 0x1d, 0xa7, 0x3a, 0xd7, 0xe1, 0x65, 0xf6,
					0x51, 0xb7, 0x23, 0xaa, 0x51, 0x02, 0xaa, 0xb0,
					0xc8, 0x7c, 0x78, 0xbb, 0x7d, 0xab, 0x1d, 0x8b,
					0x9a, 0xec, 0x5f, 0x3f, 0x20, 0x85, 0x82, 0xba,
				},
				WarnOnly: true,
			},
			6: {
				Expected: [32]byte{
					0x3d, 0x45, 0x8c, 0xfe, 0x55, 0xcc, 0x03, 0xea,
					0x1f, 0x44, 0x3f, 0x15, 0x62, 0xbe, 0xec, 0x8d,
					0xf5, 0x1c, 0x75, 0xe1, 0x4a, 0x9f, 0xcf, 0x9a,
					0x72, 0x34, 0xa1, 0x3f, 0x19, 0x8e, 0x79, 0x69,
				},
				WarnOnly: true,
			},
			7: {
				Expected: [32]byte{
					0xb1, 0xe9, 0xb3, 0x05, 0x32, 0x5c, 0x51, 0xb9,
					0x3d, 0xa5, 0x8c, 0xbf, 0x7f, 0x92, 0x51, 0x2d,
					0x8e, 0xeb, 0xfa, 0x01, 0x14, 0x3e, 0x4d, 0x88,
					0x44, 0xe4, 0x0e, 0x06, 0x2e, 0x9b, 0x6c, 0xd5,
				},
				WarnOnly: true,
			},
			8: {
				Expected: [32]byte{
					0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
					0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
					0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
					0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
				},
				WarnOnly: false,
			},
			9: {
				Expected: [32]byte{
					0x61, 0x5c, 0xfa, 0xbd, 0xec, 0x24, 0x99, 0x8b,
					0x0f, 0x42, 0x21, 0x09, 0xad, 0x59, 0xe9, 0x90,
					0xd8, 0x2b, 0x7e, 0xd2, 0xe0, 0xa5, 0x17, 0x4d,
					0x57, 0x8e, 0xcb, 0x33, 0x81, 0xf6, 0x58, 0x97,
				},
				WarnOnly: false,
			},
			10: {
				Expected: [32]byte{
					0xcb, 0xe3, 0xac, 0x91, 0xf4, 0x46, 0x77, 0xa5,
					0xd2, 0x42, 0x87, 0x38, 0xa0, 0x13, 0x45, 0x91,
					0x7c, 0x20, 0x3f, 0xdd, 0xc1, 0xb6, 0x2e, 0x5e,
					0x5b, 0xbc, 0x36, 0x55, 0x15, 0x5d, 0xfe, 0x8a,
				},
				WarnOnly: true,
			},
			11: {
				Expected: [32]byte{
					0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
					0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
					0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
					0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
				},
				WarnOnly: false,
			},
			12: {
				Expected: [32]byte{
					0x9c, 0xa2, 0x65, 0x75, 0x72, 0xb2, 0x2b, 0x43,
					0x26, 0x4f, 0xcd, 0x58, 0x33, 0xb3, 0xab, 0x31,
					0x83, 0x34, 0x26, 0x67, 0xca, 0xd9, 0xd4, 0x01,
					0x0d, 0x7d, 0x82, 0x23, 0x6d, 0xf0, 0x80, 0xbc,
				},
				WarnOnly: false,
			},
			13: {
				Expected: [32]byte{
					0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
					0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
					0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
					0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
				},
				WarnOnly: false,
			},
			14: {
				Expected: [32]byte{
					0xd7, 0xc4, 0xcc, 0x7f, 0xf7, 0x93, 0x30, 0x22,
					0xf0, 0x13, 0xe0, 0x3b, 0xde, 0xe8, 0x75, 0xb9,
					0x17, 0x20, 0xb5, 0xb8, 0x6c, 0xf1, 0x75, 0x3c,
					0xad, 0x83, 0x0f, 0x95, 0xe7, 0x91, 0x92, 0x6f,
				},
				WarnOnly: true,
			},
			15: {
				Expected: [32]byte{
					0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
					0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
					0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
					0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
				},
				WarnOnly: false,
			},
		}
	case cloudprovider.QEMU:
		return M{
			4: {
				Expected: [32]byte{
					0xbf, 0x27, 0x66, 0xfa, 0xad, 0xd1, 0x7f, 0xbf,
					0x4a, 0xeb, 0xf4, 0x1b, 0x22, 0xe5, 0x1f, 0x12,
					0x2f, 0x10, 0x08, 0x78, 0x0a, 0x56, 0xbe, 0xab,
					0x5e, 0xc3, 0x73, 0xfd, 0x77, 0x3f, 0x92, 0xd8,
				},
				WarnOnly: false,
			},
			8: {
				Expected: [32]byte{
					0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
					0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
					0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
					0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
				},
				WarnOnly: false,
			},
			9: {
				Expected: [32]byte{
					0x08, 0x76, 0xd1, 0xde, 0x84, 0xda, 0x5d, 0xfa,
					0x1b, 0xe9, 0x65, 0xbe, 0x13, 0x75, 0x5b, 0x50,
					0x71, 0xac, 0x7e, 0x14, 0x1b, 0xa1, 0xc7, 0xf2,
					0x4c, 0x1e, 0x1c, 0x99, 0xeb, 0x2d, 0xe6, 0x61,
				},
				WarnOnly: false,
			},
			11: {
				Expected: [32]byte{
					0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
					0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
					0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
					0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
				},
				WarnOnly: false,
			},
			12: {
				Expected: [32]byte{
					0x4a, 0x9b, 0xe3, 0xc0, 0xfc, 0x45, 0xb8, 0xb1,
					0xcd, 0x50, 0xa0, 0x60, 0xcd, 0xc9, 0xfd, 0xf0,
					0x76, 0x32, 0xec, 0x75, 0xc0, 0x02, 0x4f, 0x62,
					0x87, 0xbc, 0x9a, 0x9a, 0xb8, 0xe9, 0x46, 0x2a,
				},
				WarnOnly: false,
			},
			13: {
				Expected: [32]byte{
					0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
					0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
					0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
					0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
				},
				WarnOnly: false,
			},
			15: {
				Expected: [32]byte{
					0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
					0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
					0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
					0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
				},
				WarnOnly: false,
			},
		}
	default:
		return nil
	}
}
